local MODNAME = 'TrackingEvents'
local ShivvAudio = LibStub('AceAddon-3.0'):GetAddon('ShivvAudio')
local TrackingEvents = ShivvAudio:NewModule(MODNAME, 'AceEvent-3.0')

local db -- local db ref

local function EventRegister(event, reg)
	if (reg) then
		TrackingEvents:RegisterEvent(event)
	else
		TrackingEvents:UnregisterEvent(event)
	end
end

function TrackingEvents:OnInitialize()
	self:SetEnabledState(ShivvAudio.db.profile.trackingEvents)
end

function TrackingEvents:OnEnable()
	db = ShivvAudio.db.profile.events

	EventRegister('PLAYER_ACHIEVEMENT', 		(db.achievement))
	EventRegister('AUCTION_HOUSE_SHOW', 		(db.auction))
	EventRegister('AUCTION_HOUSE_CLOSED', 		(db.auction))
	EventRegister('BANKFRAME_OPENED', 			(db.bank))
	EventRegister('BANKFRAME_CLOSED', 			(db.bank))
	EventRegister('GUILDBANKFRAME_OPENED',	 	(db.bank))
	EventRegister('GUILDBANKFRAME_CLOSED',	 	(db.bank))
	EventRegister('TRADE_SKILL_SHOW', 			(db.trade))
	EventRegister('TRADE_SKILL_CLOSE', 			(db.trade))
	EventRegister('PLAYER_DEAD', 				(db.death))
	EventRegister('PLAYER_LEVEL_UP', 			(db.levelup))
	EventRegister('LOOT_OPENED', 				(db.lootopen or db.loot))
	EventRegister('LOOT_CLOSED', 				(db.lootclose or db.loot))
	EventRegister('MERCHANT_SHOW', 				(db.merchant))
	EventRegister('MERCHANT_CLOSED', 			(db.merchant))
	-- Pet Battles
	EventRegister('PET_BATTLE_OPENING_START',	(db.petopenstart or db.petbegin))
	EventRegister('PET_BATTLE_OPENING_DONE',	(db.petopendone or db.petbattle))
	EventRegister('PET_BATTLE_OVER',			(db.petover or db.petbegin or db.petbattle))
end

function TrackingEvents:OnDisable()
	EventRegister('PLAYER_ACHIEVEMENT', 		false)
	EventRegister('AUCTION_HOUSE_SHOW', 		false)
	EventRegister('AUCTION_HOUSE_CLOSED', 		false)
	EventRegister('BANKFRAME_OPENED', 			false)
	EventRegister('BANKFRAME_CLOSED', 			false)
	EventRegister('GUILDBANKFRAME_OPENED', 		false)
	EventRegister('GUILDBANKFRAME_CLOSED', 		false)
	EventRegister('TRADE_SKILL_SHOW', 			false)
	EventRegister('TRADE_SKILL_CLOSE', 			false)
	EventRegister('PLAYER_DEAD', 				false)
	EventRegister('PLAYER_LEVEL_UP', 			false)
	EventRegister('LOOT_OPENED', 				false)
	EventRegister('LOOT_CLOSED', 				false)
	EventRegister('MERCHANT_SHOW', 				false)
	EventRegister('MERCHANT_CLOSED', 			false)
	EventRegister('PET_BATTLE_OPENING_START',	false)
	EventRegister('PET_BATTLE_OPENING_START',	false)
	EventRegister('PET_BATTLE_OPENING_START',	false)
end

function TrackingEvents:PLAYER_ACHIEVEMENT()
	ShivvAudio:SoundHandler(db.achievement)
end

function TrackingEvents:AUCTION_HOUSE_SHOW()
	ShivvAudio:MusicStart('shivv-auction')
end

function TrackingEvents:AUCTION_HOUSE_CLOSED()
	ShivvAudio:MusicStop('shivv-auction')
end

function TrackingEvents:BANKFRAME_OPENED()
	ShivvAudio:MusicStart('shivv-bank')
end

function TrackingEvents:BANKFRAME_CLOSED()
	ShivvAudio:MusicStop('shivv-bank')
end

function TrackingEvents:GUILDBANKFRAME_OPENED()
	ShivvAudio:MusicStart('shivv-bank')
end

function TrackingEvents:GUILDBANKFRAME_CLOSED()
	ShivvAudio:MusicStop('shivv-bank')
end

function TrackingEvents:TRADE_SKILL_SHOW()
	ShivvAudio:MusicStart('shivv-trade')
end

function TrackingEvents:TRADE_SKILL_CLOSE()
	ShivvAudio:MusicStop('shivv-trade')
end

local timeOfDeath = GetTime()
function TrackingEvents:PLAYER_DEAD()
	if (GetTime() > timeOfDeath) then -- only fire once per 10 seconds (blizzard bug, death event sometimes fires multiple times)
		ShivvAudio:SoundHandler(db.death)
		timeOfDeath = GetTime() + 10
	end
end

function TrackingEvents:PLAYER_LEVEL_UP()
	ShivvAudio:SoundHandler(db.levelup)
end

function TrackingEvents:LOOT_OPENED()
	ShivvAudio:SoundHandler(db.lootopen)
	ShivvAudio:MusicStart('shivv-loot')
end

function TrackingEvents:LOOT_CLOSED()
	ShivvAudio:SoundHandler(db.lootclose)
	ShivvAudio:MusicStop('shivv-loot')
end

function TrackingEvents:MERCHANT_SHOW()
	ShivvAudio:MusicStart('shivv-merchant')
end

function TrackingEvents:MERCHANT_CLOSED()
	ShivvAudio:MusicStop('shivv-merchant')
end

-- Pet Battles!

function TrackingEvents:PET_BATTLE_OPENING_START()
	ShivvAudio:SoundHandler(db.petopenstart)
	ShivvAudio:MusicStart('shivv-pet-begin')	-- petbegin
end

function TrackingEvents:PET_BATTLE_OPENING_DONE()
	ShivvAudio:SoundHandler(db.petopendone)
	ShivvAudio:MusicStart('shivv-pet-battle')	-- petbattle
end

function TrackingEvents:PET_BATTLE_OVER()
	ShivvAudio:SoundHandler(db.petover)
	ShivvAudio:MusicStop('shivv-pet-begin')
	ShivvAudio:MusicStop('shivv-pet-battle')
end
